@@ -57,7 +57,7 @@ class OpenFileEventFilter(QObject):
     def eventFilter(self, obj, event):
         if event.type() == QtCore.QEvent.FileOpen:
             if len(self.windows) >= 1:
-                self.windows[0].set_url(event.url().toEncoded())
+                self.windows[0].pay_from_URI(event.url().toEncoded())
                 return True
         return False
 
@@ -173,6 +173,7 @@ class ElectrumGui:
         if action is not None:
             import installwizard
             wizard = installwizard.InstallWizard(self.config, self.network, storage)
+            wizard.show()
             try:
                 wallet = wizard.run(action)
             except BaseException as e:
